@@ -1,12 +1,14 @@
 package Module::DataPack;
 
-our $DATE = '2015-07-04'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-07-05'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+use File::Slurper qw(read_binary write_binary);
+
 require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(datapack_modules);
@@ -107,11 +109,7 @@ sub datapack_modules {
             my $path = Module::Path::More::module_path(
                 module => $mod, find_pmc=>0);
             die "Can't find module '$mod_pm'" unless $path;
-            $module_srcs{$mod_pm} = do {
-                local $/;
-                open my($fh), "<", $path or die "Can't open $path: $!";
-                ~~<$fh>;
-            };
+            $module_srcs{$mod_pm} = read_binary($path);
         }
     }
 
@@ -219,8 +217,8 @@ _
             return [409, "Won't overwrite existing file '$outfile'"]
                 unless $args{overwrite};
         }
-        open my($fh), ">", $outfile or die "Can't write to '$outfile': $!";
-        print $fh join("", @res);
+        write_binary($outfile, join("", @res))
+            or die "Can't write to '$outfile': $!";
         return [200, "OK, written to '$outfile'"];
     } else {
         return [200, "OK", join("", @res)];
@@ -244,7 +242,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.06 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-07-04.
+This document describes version 0.07 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-07-05.
 
 =head1 SEE ALSO
 
